@@ -315,6 +315,7 @@ class ControlPoint:
         while not self.ready:
 
             try:
+                self.logger.info('re_connect() starting connect')
                 await self.connect(fast=True)
 
                 while True:
@@ -334,12 +335,20 @@ class ControlPoint:
         self.closed_socket.close()
         self.closed_socket = None
 
-        self.watchdog_timer.reset()
+        if self.watchdog_timer:
+            self.watchdog_timer.reset()
 
     async def set(self, identifier: str, action: str, params: object = None):
         '''Sends an action for a device.'''
 
-        await self.connected_ready.wait()
+        while not self.connected_ready.is_set():
+            self.logger.error('set() not ready - attempting to connect')
+            try:
+                await self.re_connect()
+            except ControlPointError as error:
+                self.logger.error('set() connection failed - trying again')
+
+        # await self.connected_ready.wait()
 
         message = ControlPointProtocol.set(identifier, action, params)
         success = False
